@@ -16,7 +16,7 @@ sub remove_snapshot_root {
 		$snapshot_root = $args;
 	}
 	else {
-		$snapshot_root = "/home/travis/build/rsnapshot/rsnapshot//t/support/snapshots";
+		$snapshot_root = "/home/sam/src/rsnapshot//t/support/snapshots";
 	}
 
 	if(-d "$snapshot_root"){
@@ -31,12 +31,12 @@ sub execute {
 sub rsnapshot {
 	my $args = shift(@_);
 
-	return execute("/home/travis/perl5/perlbrew/perls/5.18/bin/perl /home/travis/build/rsnapshot/rsnapshot//rsnapshot $args >/dev/null 2>&1");
+	return execute("/usr/bin/perl /home/sam/src/rsnapshot//rsnapshot $args >/dev/null 2>&1");
 }
 
 sub rsnapshot_output {
 	my $args = shift(@_);
-	return `/home/travis/perl5/perlbrew/perls/5.18/bin/perl /home/travis/build/rsnapshot/rsnapshot//rsnapshot $args`;
+	return `/usr/bin/perl /home/sam/src/rsnapshot//rsnapshot $args`;
 }
 
 1;
